@@ -1,13 +1,18 @@
+import sys
 from pathlib import Path
 
-import toml
+if sys.version_info >= (3, 11):
+    import tomllib
+else:
+    import tomli as tomllib
 
 from beanie import __version__
 
 
 def parse_version_from_pyproject():
     pyproject = Path(__file__).parent.parent / "pyproject.toml"
-    toml_data = toml.loads(pyproject.read_text())
+    with pyproject.open("rb") as f:
+        toml_data = tomllib.load(f)
     return toml_data["project"]["version"]
 
 
